@@ -1,4 +1,5 @@
-from PySide6.QtWidgets import QPushButton, QApplication
+from QtFrameless.qt_api import QPushButton, QApplication
+
 
 class TitleBarButton(QPushButton):
     """Standard Buttons for closing and minimizing the window."""
@@ -6,8 +7,8 @@ class TitleBarButton(QPushButton):
     def __init__(self, prop, parent=None):
         """Construct the standard window control buttons."""
         super().__init__(parent=parent)
-        self.setFixedHeight(22)
-        self.setFixedWidth(22)
+        self.setFixedHeight(20)
+        self.setFixedWidth(20)
         self.setProperty(prop, "true")
         self.clicked.connect(self.window_action)
 
